scipy.sparse.coo_matrix
=======================

.. currentmodule:: scipy.sparse

.. autoclass:: coo_matrix

   

   .. HACK
      .. autosummary::
         :toctree:
      
         coo_matrix.__init__
         coo_matrix.asformat
         coo_matrix.asfptype
         coo_matrix.astype
         coo_matrix.conj
         coo_matrix.conjugate
         coo_matrix.copy
         coo_matrix.diagonal
         coo_matrix.dot
         coo_matrix.getH
         coo_matrix.get_shape
         coo_matrix.getcol
         coo_matrix.getformat
         coo_matrix.getmaxprint
         coo_matrix.getnnz
         coo_matrix.getrow
         coo_matrix.mean
         coo_matrix.multiply
         coo_matrix.nonzero
         coo_matrix.reshape
         coo_matrix.set_shape
         coo_matrix.setdiag
         coo_matrix.sum
         coo_matrix.toarray
         coo_matrix.tobsr
         coo_matrix.tocoo
         coo_matrix.tocsc
         coo_matrix.tocsr
         coo_matrix.todense
         coo_matrix.todia
         coo_matrix.todok
         coo_matrix.tolil
         coo_matrix.transpose



   

   .. HACK
      .. autosummary::
         :toctree:
      
         coo_matrix.dtype
         coo_matrix.nnz
         coo_matrix.shape

